Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
sync.Mutex
ConfigFile *string
DataDir *string `` /* 154-byte string literal not displayed */
LogDir *string `` /* 142-byte string literal not displayed */
Network *string `` /* 166-byte string literal not displayed */
LogLevel *string `` /* 138-byte string literal not displayed */
Subsystems *cli.StringSlice `` /* 150-byte string literal not displayed */
Group *string `` /* 176-byte string literal not displayed */
NoDiscovery *bool `category:"node" name:"NoDiscovery" description:"disables zeroconf peer autodiscovery"`
AddPeers *cli.StringSlice `` /* 155-byte string literal not displayed */
ConnectPeers *cli.StringSlice `` /* 181-byte string literal not displayed */
MaxPeers *int `` /* 160-byte string literal not displayed */
Listeners *cli.StringSlice `` /* 158-byte string literal not displayed */
DisableListen *bool `` /* 161-byte string literal not displayed */
DisableBanning *bool `` /* 146-byte string literal not displayed */
BanDuration *time.Duration `` /* 160-byte string literal not displayed */
BanThreshold *int `` /* 164-byte string literal not displayed */
Whitelists *cli.StringSlice `` /* 152-byte string literal not displayed */
Username *string `` /* 144-byte string literal not displayed */
Password *string `` /* 160-byte string literal not displayed */
ServerUser *string `` /* 144-byte string literal not displayed */
ServerPass *string `` /* 160-byte string literal not displayed */
LimitUser *string `` /* 128-byte string literal not displayed */
LimitPass *string `` /* 148-byte string literal not displayed */
RPCConnect *string `` /* 140-byte string literal not displayed */
RPCListeners *cli.StringSlice `` /* 157-byte string literal not displayed */
RPCCert *string `` /* 139-byte string literal not displayed */
RPCKey *string `` /* 129-byte string literal not displayed */
RPCMaxClients *int `` /* 163-byte string literal not displayed */
RPCMaxWebsockets *int `` /* 172-byte string literal not displayed */
RPCMaxConcurrentReqs *int `` /* 187-byte string literal not displayed */
RPCQuirks *bool `` /* 145-byte string literal not displayed */
DisableRPC *bool `category:"rpc" name:"DisableRPC" description:"disable rpc servers" type:"switch" model:"DisableRPC" featured:"false"`
TLS *bool `category:"tls" name:"TLS" description:"enable TLS for RPC connections" type:"switch" model:"TLS" featured:"false"`
DisableDNSSeed *bool `` /* 145-byte string literal not displayed */
ExternalIPs *cli.StringSlice `` /* 166-byte string literal not displayed */
Proxy *string `` /* 160-byte string literal not displayed */
ProxyUser *string `` /* 140-byte string literal not displayed */
ProxyPass *string `` /* 156-byte string literal not displayed */
OnionProxy *string `` /* 158-byte string literal not displayed */
OnionProxyUser *string `` /* 142-byte string literal not displayed */
OnionProxyPass *string `` /* 162-byte string literal not displayed */
Onion *bool `category:"proxy" name:"Onion" description:"enable tor proxy" type:"switch" model:"Onion" featured:"false"`
TorIsolation *bool `` /* 156-byte string literal not displayed */
TestNet3 *bool
RegressionTest *bool
SimNet *bool
AddCheckpoints *cli.StringSlice `category:"debug" name:"AddCheckpoints" description:"add custom checkpoints"`
DisableCheckpoints *bool `category:"debug" name:"Disable Checkpoints" description:"disables all checkpoints"`
DbType *string `category:"debug" name:"Db Type" description:"type of database storage engine to use (only one right now)"`
Profile *string `category:"debug" name:"Profile" description:"http profiling on given port (1024-40000)"`
CPUProfile *string `category:"debug" name:"CPU Profile" description:"write cpu profile to this file"`
Upnp *bool `category:"node" name:"Upnp" description:"enable UPNP for NAT traversal"`
MinRelayTxFee *float64 `category:"policy" name:"Min Relay Tx Fee" description:"the minimum transaction fee in DUO/kB to be considered a non-zero fee"`
FreeTxRelayLimit *float64 `` /* 163-byte string literal not displayed */
NoRelayPriority *bool `` /* 135-byte string literal not displayed */
TrickleInterval *time.Duration `` /* 127-byte string literal not displayed */
MaxOrphanTxs *int `category:"policy" name:"Max Orphan Txs" description:"max number of orphan transactions to keep in memory"`
Algo *string `category:"mining" name:"Algo" description:"algorithm to mine, random is best"`
Generate *bool `category:"mining" name:"Generate" description:"turn on built in CPU miner"`
GenThreads *int `category:"mining" name:"Gen Threads" description:"number of CPU threads to mine using"`
NoController *bool `category:"node" name:"Disable Controller" description:"disables the zeroconf peer discovery/miner controller system"`
MiningAddrs *cli.StringSlice `category:"mining" name:"Mining Addrs" description:"addresses to pay block rewards to (TODO, make this auto)"`
MinerPass *string `category:"mining" name:"Miner Pass" description:"password that encrypts the connection to the mining controller"`
BlockMinSize *int `category:"mining" name:"Block Min Size" description:"mininum block size in bytes to be used when creating a block"`
BlockMaxSize *int `category:"mining" name:"Block Max Size" description:"maximum block size in bytes to be used when creating a block"`
BlockMinWeight *int `category:"mining" name:"Block Min Weight" description:"mininum block weight to be used when creating a block"`
BlockMaxWeight *int `category:"mining" name:"Block Max Weight" description:"maximum block weight to be used when creating a block"`
BlockPrioritySize *int `` /* 133-byte string literal not displayed */
UserAgentComments *cli.StringSlice `category:"node" name:"User Agent Comments" description:"Comment to add to the user agent -- See BIP 14 for more information"`
NoPeerBloomFilters *bool `category:"node" name:"No Peer Bloom Filters" description:"disable bloom filtering support"`
NoCFilters *bool `category:"node" name:"No CFilters" description:"disable committed filtering (CF) support"`
SigCacheMaxSize *int `category:"node" name:"Sig Cache Max Size" description:"the maximum number of entries in the signature verification cache"`
BlocksOnly *bool `category:"node" name:"BlockC Only" description:"do not accept transactions from remote peers"`
TxIndex *bool `` /* 159-byte string literal not displayed */
AddrIndex *bool `` /* 147-byte string literal not displayed */
RelayNonStd *bool `` /* 140-byte string literal not displayed */
RejectNonStd *bool `` /* 142-byte string literal not displayed */
TLSSkipVerify *bool `category:"tls" name:"TLS Skip Verify" description:"skip TLS certificate verification (ignore CA errors)"`
Wallet *bool
NoInitialLoad *bool
WalletPass *string `` /* 158-byte string literal not displayed */
WalletServer *string `` /* 133-byte string literal not displayed */
CAFile *string `` /* 163-byte string literal not displayed */
OneTimeTLSKey *bool `` /* 187-byte string literal not displayed */
ServerTLS *bool `` /* 154-byte string literal not displayed */
WalletRPCListeners *cli.StringSlice `` /* 178-byte string literal not displayed */
WalletRPCMaxClients *int `` /* 191-byte string literal not displayed */
WalletRPCMaxWebsockets *int `` /* 203-byte string literal not displayed */
ExperimentalRPCListeners *cli.StringSlice `` /* 199-byte string literal not displayed */
NodeOff *bool `category:"debug" name:"NodeOff" description:"turn off the node backend" type:"switch" model:"NodeOff" featured:"false"`
TestNodeOff *bool `` /* 137-byte string literal not displayed */
WalletOff *bool `category:"debug" name:"WalletOff" description:"turn off the wallet backend" type:"switch" model:"WalletOff" featured:"false"`
}
Config is nolint
type Field ¶
type Field struct {
Group string `json:"group"`
Type string `json:"type"`
Name string `json:"label"`
Description string `json:"help"`
InputType string `json:"inputType"`
Featured string `json:"featured"`
Model string `json:"model"`
Datatype string `json:"datatype"`
Options []string `json:"options"`
}
Source Files
¶
- pod.go
Click to show internal directories.
Click to hide internal directories.